# eric7.UI.UserInterface

Module implementing the main user interface.

### Global Attributes

SSL_AVAILABLE

### Classes

UserInterface | Class implementing the main user interface.
UserInterfaceSide | Class defining the supported sides of the user interface.

### Functions

None

## UserInterface

Class implementing the main user interface.

### Signals

appendStderr(str)
  emitted to write data to stderr logger
appendStdout(str)
  emitted to write data to stdout logger
mainPasswordChanged(str, str)
  emitted after the main password has been changed with the old and the new password
onlineStateChanged(online)
  emitted to indicate a change of the network state
preferencesChanged()
  emitted after the preferences were changed
reloadAPIs()
  emitted to reload the api information
showMenu(str, QMenu)
  emitted when a menu is about to be shown. The name of the menu and a reference to the menu are given.

### Derived from

EricMainWindow

### Class Attributes

ErrorLogFileName
ReleaseMode
maxFilePathLen
maxMenuFilePathLen

### Class Methods

None

### Methods

UserInterface | Constructor
__TBMenuTriggered | Private method to handle the toggle of a toolbar via the Window-> Toolbars submenu.
__TBPopupMenuTriggered | Private method to handle the toggle of a toolbar via the QMainWindow Toolbars popup menu.
__TRPreviewer | Private slot to start the Translation Previewer executable.
__UIPreviewer | Private slot to start the UI Previewer executable.
__activateBrowser | Private slot to handle the activation of the file browser.
__activateCondaWidget | Private slot to handle the activation of the Conda manager widget.
__activateFindFileWidget | Private slot to activate the Find In Files widget.
__activateFindLocationWidget | Private method to activate the Find File widget.
__activateHelpViewerWidget | Private method to activate the embedded Help Viewer window.
__activateIRC | Private slot to handle the activation of the IRC window.
__activateLogViewer | Private slot to handle the activation of the Log Viewer.
__activateMicroPython | Private slot to handle the activation of the MicroPython widget.
__activateMultiProjectBrowser | Private slot to handle the activation of the project browser.
__activateNumbersViewer | Private slot to handle the activation of the Numbers Viewer.
__activatePipWidget | Private slot to handle the activation of the PyPI manager widget.
__activateProjectBrowser | Private slot to handle the activation of the project browser.
__activateShell | Private slot to handle the activation of the Shell window.
__activateSymbolsViewer | Private slot to handle the activation of the Symbols Viewer.
__activateTaskViewer | Private slot to handle the activation of the Task Viewer.
__activateTemplateViewer | Private slot to handle the activation of the Template Viewer.
__activateVcsStatusList | Private slot to activate the VCS Status List.
__activateViewProfile | Private slot to activate a view profile.
__activateViewmanager | Private slot to handle the activation of the current editor.
__assistant | Private slot to start the Qt-Assistant executable.
__bottomSidebarCurrentChanged | Private slot handling a change of the current index of the Bottom Sidebar.
__checkActions | Private slot to check some actions for their enable/disable status.
__checkCrashSessionExists | Private method to check for the existence of crash session files and select the one to open.
__chmViewer | Private slot to start the win help viewer to show *.chm files.
__cleanCrashSessions | Private slot to clean all stale crash sessions.
__clearPrivateData | Private slot to clear the private data lists.
__commitData | Private slot to commit unsaved data when instructed by the desktop session manager.
__compareFiles | Private slot to handle the Compare Files dialog.
__compareFilesSbs | Private slot to handle the Compare Files dialog.
__configShortcuts | Private slot to configure the keyboard shortcuts.
__configToolBars | Private slot to configure the various toolbars.
__configViewProfiles | Private slot to configure the various view profiles.
__connectToWebBrowser | Private method to connect to a started web browser.
__copyVersions | Private method to generated version information and copy that to the clipboard.
__crashSessionFilePath | Private method to generate a path name for a unique crash session file.
__createDockWindow | Private method to create a dock window with common properties.
__createLayout | Private method to create the layout of the various windows.
__createObjects | Private method to create the various application objects.
__createSidebarsLayout | Private method to create the Sidebars layout.
__createTestingDialog | Private slot to generate the testing dialog on demand.
__createToolboxesLayout | Private method to create the Toolboxes layout.
__customViewer | Private slot to start a custom viewer.
__debuggingDone | Private slot to handle the end of a debugging session.
__debuggingStarted | Private slot to handle the start of a debugging session.
__deinstallPlugin | Private slot to show a dialog to uninstall a plugin.
__deleteCrashSession | Private slot to delete the crash session file.
__designer | Private slot to start the Qt-Designer executable.
__editPixmap | Private slot to show a pixmap in a dialog.
__editorOpened | Private slot to handle the editorOpened signal.
__exportPreferences | Private slot to export the current preferences.
__exportShortcuts | Private slot to export the keyboard shortcuts.
__exportTheme | Private slot to export the current theme to a file.
__getCrashedSessions | Private method to get a list of crash session file paths of crashed sessions.
__getFloatingGeometry | Private method to get the geometry of a floating windows.
__hToolboxCurrentChanged | Private slot handling a change of the current index of the Horizontal Toolbox.
__hasErrorLog | Private method to check, if an error log file exists.
__helpViewer | Private slot to start an empty help viewer/web browser.
__importPreferences | Private slot to from eric7 import Preferences.
__importShortcuts | Private slot to import the keyboard shortcuts.
__importTheme | Private slot to import a previously exported theme.
__initActions | Private method to define the user interface actions.
__initDebugToolbarsLayout | Private slot to initialize the toolbars layout for the debug profile.
__initEricDocAction | Private slot to initialize the action to show the eric documentation.
__initExternalToolsActions | Private slot to create actions for the configured external tools.
__initMenus | Private slot to create the menus.
__initPySideDocActions | Private slot to initialize the actions to show the PySide documentation.
__initPythonDocActions | Private slot to initialize the actions to show the Python documentation.
__initQtDocActions | Private slot to initialize the action to show the Qt documentation.
__initStatusbar | Private slot to set up the status bar.
__initToolbars | Private slot to create the toolbars.
__initToolsMenus | Private slot to initialize the various tool menus.
__installDownloadedPlugins | Private slot to handle the installation of plugins downloaded via the plugin repository viewer.
__installPlugins | Private slot to show a dialog to install a new plugin.
__ircAutoConnected | Private slot handling the automatic connection of the IRC client.
__lastEditorClosed | Private slot to handle the lastEditorClosed signal.
__launchExternalWebBrowser | Private method to start an external web browser and communicate with it.
__linguist | Private slot to start the Qt-Linguist executable.
__loadCrashSession | Private slot to load a crash session.
__loadSessionFromFile | Private slot to load a session from disk.
__mainPasswordChanged | Private slot to handle the change of the main password.
__newProject | Private slot to handle the NewProject signal.
__newWindow | Private slot to start a new instance of eric.
__onlineStateChanged | Private slot handling changes in online state.
__openHexEditor | Private slot to open the hex editor window.
__openMiniEditor | Private slot to show a mini editor window.
__openOnStartup | Private method to open the last file, project or multiproject.
__openPdfViewer | Private slot to open the PDF viewer window.
__performUpgrade | Private method to perform the requested upgrade operation.
__pluginInstallFinished | Private slot to handle the finishing of the plugin install dialog.
__pluginsConfigure | Private slot to show the plugin manager configuration page.
__populateToolbarsMenu | Private method to populate a toolbars menu.
__preferencesChanged | Private slot to handle a change of the preferences.
__processToolStderr | Private slot to handle the readyReadStderr signal of a tool process.
__processToolStdout | Private slot to handle the readyReadStdout signal of a tool process.
__programChange | Private slot to handle the programChange signal.
__projectClosed | Private slot to handle the projectClosed signal.
__projectOpened | Private slot to handle the projectOpened signal.
__quit | Private method to quit the application.
__readCrashSession | Private method to check for and read a crash session.
__readSession | Private slot to read in the session file (.esj).
__readTasks | Private slot to read in the tasks file (.etj).
__reloadAPIs | Private slot to reload the api information.
__reportBug | Private slot to handle the Report Bug dialog.
__requestFeature | Private slot to handle the Feature Request dialog.
__rerunFailedTests | Private slot to display the testing dialog and rerun all failed tests of the last run.
__restart | Private method to restart the application.
__restartTest | Private slot to display the testing dialog and rerun the last test run.
__saveCurrentViewProfile | Private slot to save the window geometries of the active profile.
__saveSessionToFile | Private slot to save a session to disk.
__setEditProfile | Private slot to activate the edit view profile.
__setWindowCaption | Private method to set the caption of the Main Window.
__setupDockWindow | Private method to configure the dock window created with __createDockWindow().
__showCertificatesDialog | Private slot to show the certificates management dialog.
__showEricDoc | Private slot to show the Eric documentation.
__showErrorLog | Private slot to show the most recent error log message.
__showExternalTools | Private slot to display a dialog show a list of external tools used by eric.
__showExtrasMenu | Private slot to display the Extras menu.
__showFileMenu | Private slot to display the File menu.
__showHelpMenu | Private slot to display the Help menu.
__showInstallInfo | Private slot to show a dialog containing information about the installation process.
__showNext | Private slot used to show the next tab or file.
__showPixmap | Private slot to show a pixmap in a dialog.
__showPluginInfo | Private slot to show the plugin info dialog.
__showPluginToolsMenu | Private slot to show the Plugin Tools menu.
__showPluginsAvailable | Private slot to show the plugins available for download.
__showPrevious | Private slot used to show the previous tab or file.
__showPyQtDoc | Private slot to show the PyQt5/6 documentation.
__showPySideDoc | Private slot to show the PySide2/PySide6 documentation.
__showPythonDoc | Private slot to show the Python 3 documentation.
__showQtDoc | Private method to show the Qt documentation.
__showSessionsMenu | Private slot to mofify the state of some session actions.
__showSettingsMenu | Private slot to show the Settings menu.
__showSubWindowMenu | Private slot to display the Window menu of the Window menu.
__showSvg | Private slot to show a SVG file in a dialog.
__showSystemEmailClient | Private slot to show the system email dialog.
__showToolGroupsMenu | Private slot to display the Tool Groups menu.
__showToolbarsMenu | Private slot to display the Toolbars menu.
__showUml | Private slot to show an eric graphics file in a dialog.
__showUserToolsMenu | Private slot to display the User Tools menu.
__showVersions | Private slot to handle the Versions dialog.
__showWindowMenu | Private slot to display the Window menu.
__showWizardsMenu | Private slot to display the Wizards menu.
__shutdown | Private method to perform all necessary steps to close down the IDE.
__snapshot | Private slot to start the snapshot tool.
__sqlBrowser | Private slot to start the SQL browser tool.
__sslErrors | Private slot to handle SSL errors.
__startFido2SecurityKeyMgmt | Private slot to start the FIDO2 Security Key Management.
__startTestProject | Private slot for displaying the testing dialog and run the test for the current project.
__startTestScript | Private slot for displaying the testing dialog and run the current script.
__startTesting | Private slot for displaying the testing dialog.
__startToolProcess | Private slot to start an external tool process.
__startWebBrowser | Private slot to start the eric web browser.
__switchTab | Private slot used to switch between the current and the previous current tab.
__testingStopped | Private slot to handle the end of a test run.
__toggleBottomSidebar | Private slot to handle the toggle of the bottom sidebar window.
__toggleHorizontalToolbox | Private slot to handle the toggle of the Horizontal Toolbox window.
__toggleLeftSidebar | Private slot to handle the toggle of the left sidebar window.
__toggleLeftToolbox | Private slot to handle the toggle of the Left Toolbox window.
__toggleRightSidebar | Private slot to handle the toggle of the right sidebar window.
__toggleRightToolbox | Private slot to handle the toggle of the Right Toolbox window.
__toggleWindow | Private method to toggle a workspace editor window.
__toolActionTriggered | Private slot called by external tools toolbar actions.
__toolExecute | Private slot to execute a particular tool.
__toolFinished | Private slot to handle the finished signal of a tool process.
__toolGroupSelected | Private slot to set the current tool group.
__toolGroupsConfiguration | Private slot to handle the tool groups configuration menu entry.
__toolsConfiguration | Private slot to handle the tools configuration menu entry.
__updateExternalToolsActions | Private method to update the external tools actions for the current tool group.
__webBrowser | Private slot to start the eric web browser.
__webBrowserFinished | Private slot handling the end of the external web browser process.
__webBrowserShutdown | Private method to shut down the web browser.
__whatsThis | Private slot called in to enter Whats This mode.
__writeCrashSession | Private slot to write a crash session file.
__writeSession | Private slot to write the session data to a JSON file (.esj).
__writeTasks | Private slot to write the tasks data to a JSON file (.etj).
activateCodeDocumentationViewer | Public slot to handle the activation of the Code Documentation Viewer.
activateCooperationViewer | Public slot to handle the activation of the cooperation window.
activateDebugViewer | Public slot to handle the activation of the debug viewer.
activateLeftRightSidebarWidget | Public method to activate the given widget in the left or right sidebar.
activatePluginRepositoryViewer | Public slot to activate the plugin repository viewer.
activateVirtualenvManager | Public slot to activate the virtual environments manager widget.
addEricActions | Public method to add actions to the list of actions.
addSideWidget | Public method to add a widget to the sides.
appendToStderr | Public slot to append text to the stderr log viewer tab.
appendToStdout | Public slot to append text to the stdout log viewer tab.
autoConnectIrc | Public method to initiate the IRC auto connection.
checkConfigurationStatus | Public method to check, if eric has been configured.
checkForErrorLog | Public method to check for the presence of an error log and ask the user, what to do with it.
checkPluginUpdatesAvailable | Public method to check the availability of updates of plug-ins.
checkProjectsWorkspace | Public method to check, if a projects workspace has been configured.
closeEvent | Protected event handler for the close event.
createPopupMenu | Public method to create the toolbars menu for Qt.
documentationViewer | Public method to provide a reference to the code documentation viewer.
dragEnterEvent | Protected method to handle the drag enter event.
dragLeaveEvent | Protected method to handle the drag leave event.
dragMoveEvent | Protected method to handle the drag move event.
dropEvent | Protected method to handle the drop event.
getActions | Public method to get a list of all actions.
getLayoutType | Public method to get the current layout type.
getLocale | Public method to get the locale of the IDE.
getMenu | Public method to get a reference to a specific menu.
getMenuAction | Public method to get a reference to an action of a menu.
getMenuBarAction | Public method to get a reference to an action of the main menu.
getOriginalPathString | Public method to get the original PATH environment variable (i.e.
getToolbar | Public method to get a reference to a specific toolbar.
getToolbarsByCategory | Public method to get a list of toolbars belonging to a given toolbar category.
getViewProfile | Public method to get the current view profile.
handleUrl | Public slot to handle opening a URL.
isEricServerConnected | Public method to check, if a connection to an eric-ide server has been established.
isOnline | Public method to get the online state.
launchHelpViewer | Public slot to start the help viewer/web browser.
networkAccessManager | Public method to get a reference to the network access manager object.
performVersionCheck | Public method to check for an update even if not installed via PyPI.
processArgs | Public method to process the command line args passed to the UI.
processInstallInfoFile | Public method to process the file containing installation information.
registerToolbar | Public method to register a toolbar.
removeEricActions | Public method to remove actions from the list of actions.
removeSideWidget | Public method to remove a widget added using addSideWidget().
reregisterToolbar | Public method to change the visible text for the named toolbar.
setDebugProfile | Public slot to activate the debug view profile.
setLeftRightSidebarWidgetIcon | Public method to set the icon of the given widget in the left or right sidebar.
showEmailDialog | Public slot to show the email dialog in a given mode.
showEvent | Protected method to handle the show event.
showFindFileByNameDialog | Public slot to show the Find File by Name dialog.
showFindFilesWidget | Public slot to show the Find In Files widget.
showFindLocationWidget | Public method to show the Find File widget.
showLogViewer | Public method to show the Log-Viewer.
showNotification | Public method to show a desktop notification.
showPreferences | Public slot to set the preferences.
showReplaceFilesWidget | Public slot to show the Find In Files widget in replace mode.
showSideWidget | Public method to show a specific widget placed in the side widgets.
unregisterToolbar | Public method to unregister a toolbar.
upgradeEric | Public slot to upgrade the eric-ide package of the eric7 environment.
upgradeEricPyQt | Public slot to upgrade the eric-ide and PyQt packages of the eric7 environment.
upgradePyQt | Public slot to upgrade the PyQt packages of the eric7 environment.
versionIsNewer | Public method to check, if the eric version is good compared to the required version.

### Static Methods

None

#### UserInterface (Constructor)

UserInterface(app, locale, splash, plugin, disabledPlugins, noOpenAtStartup, noCrashOpenAtStartup, disableCrashSession, restartArguments, originalPathString, )

Constructor

app (EricApplication)
  reference to the application object
locale (str)
  locale to be used by the UI
splash (UI.SplashScreen.SplashScreen)
  reference to the splashscreen
plugin (str)
  filename of a plug-in to be loaded (used for plugin development)
disabledPlugins (list of str)
  list of plug-ins that have been disabled via the command line parameters '--disable-plugin='
noOpenAtStartup (bool)
  flag indicating that the open at startup option should not be executed
noCrashOpenAtStartup (bool)
  flag indicating to ignore any crash session file found at statup
disableCrashSession (bool)
  flag indicating to disable the crash session support
restartArguments (list of str)
  list of command line parameters to be used for a restart
originalPathString (str)
  original PATH environment variable

#### UserInterface.__TBMenuTriggered

__TBMenuTriggered(act)

Private method to handle the toggle of a toolbar via the Window-> Toolbars submenu.

act (QAction)
  reference to the action that was triggered

#### UserInterface.__TBPopupMenuTriggered

__TBPopupMenuTriggered(act)

Private method to handle the toggle of a toolbar via the QMainWindow Toolbars popup menu.

act (QAction)
  reference to the action that was triggered

#### UserInterface.__TRPreviewer

__TRPreviewer(fileNames=None, ignore=False)

Private slot to start the Translation Previewer executable.

fileNames (list of str)
  filenames of forms and/or translations to be previewed
ignore (bool)
  flag indicating non existing files should be ignored

#### UserInterface.__UIPreviewer

__UIPreviewer(fn=None)

Private slot to start the UI Previewer executable.

fn (str)
  filename of the form to be previewed

#### UserInterface.__activateBrowser

__activateBrowser()

Private slot to handle the activation of the file browser.

#### UserInterface.__activateCondaWidget

__activateCondaWidget()

Private slot to handle the activation of the Conda manager widget.

#### UserInterface.__activateFindFileWidget

__activateFindFileWidget()

Private slot to activate the Find In Files widget.

#### UserInterface.__activateFindLocationWidget

__activateFindLocationWidget()

Private method to activate the Find File widget.

#### UserInterface.__activateHelpViewerWidget

__activateHelpViewerWidget(urlStr=None)

Private method to activate the embedded Help Viewer window.

urlStr (str)
  URL to be shown

#### UserInterface.__activateIRC

__activateIRC()

Private slot to handle the activation of the IRC window.

#### UserInterface.__activateLogViewer

__activateLogViewer()

Private slot to handle the activation of the Log Viewer.

#### UserInterface.__activateMicroPython

__activateMicroPython()

Private slot to handle the activation of the MicroPython widget.

#### UserInterface.__activateMultiProjectBrowser

__activateMultiProjectBrowser()

Private slot to handle the activation of the project browser.

#### UserInterface.__activateNumbersViewer

__activateNumbersViewer()

Private slot to handle the activation of the Numbers Viewer.

#### UserInterface.__activatePipWidget

__activatePipWidget()

Private slot to handle the activation of the PyPI manager widget.

#### UserInterface.__activateProjectBrowser

__activateProjectBrowser()

Private slot to handle the activation of the project browser.

#### UserInterface.__activateShell

__activateShell()

Private slot to handle the activation of the Shell window.

#### UserInterface.__activateSymbolsViewer

__activateSymbolsViewer()

Private slot to handle the activation of the Symbols Viewer.

#### UserInterface.__activateTaskViewer

__activateTaskViewer()

Private slot to handle the activation of the Task Viewer.

#### UserInterface.__activateTemplateViewer

__activateTemplateViewer()

Private slot to handle the activation of the Template Viewer.

#### UserInterface.__activateVcsStatusList

__activateVcsStatusList()

Private slot to activate the VCS Status List.

#### UserInterface.__activateViewProfile

__activateViewProfile(name, save=True)

Private slot to activate a view profile.

name (str)
  name of the profile to be activated
save (bool)
  flag indicating that the current profile should be saved

#### UserInterface.__activateViewmanager

__activateViewmanager()

Private slot to handle the activation of the current editor.

#### UserInterface.__assistant

__assistant(home=None)

Private slot to start the Qt-Assistant executable.

home (str)
  full pathname of a file to display

#### UserInterface.__bottomSidebarCurrentChanged

__bottomSidebarCurrentChanged(index)

Private slot handling a change of the current index of the Bottom Sidebar.

index (int)
  current index of the bottom sidebar

#### UserInterface.__checkActions

__checkActions(editor)

Private slot to check some actions for their enable/disable status.

editor (Editor)
  editor window

#### UserInterface.__checkCrashSessionExists

__checkCrashSessionExists()

Private method to check for the existence of crash session files and select the one to open.

Return:
  file path of the crash session file to open. An empty string indicates that no crash session file should be opened or exists.

Return Type:
  str

#### UserInterface.__chmViewer

__chmViewer(home=None)

Private slot to start the win help viewer to show *.chm files.

home (str)
  full pathname of a file to display

#### UserInterface.__cleanCrashSessions

__cleanCrashSessions()

Private slot to clean all stale crash sessions.

#### UserInterface.__clearPrivateData

__clearPrivateData()

Private slot to clear the private data lists.

#### UserInterface.__commitData

__commitData(manager: QSessionManager)

Private slot to commit unsaved data when instructed by the desktop session manager.

manager (QSessionManager)
  reference to the desktop session manager

#### UserInterface.__compareFiles

__compareFiles()

Private slot to handle the Compare Files dialog.

#### UserInterface.__compareFilesSbs

__compareFilesSbs()

Private slot to handle the Compare Files dialog.

#### UserInterface.__configShortcuts

__configShortcuts()

Private slot to configure the keyboard shortcuts.

#### UserInterface.__configToolBars

__configToolBars()

Private slot to configure the various toolbars.

#### UserInterface.__configViewProfiles

__configViewProfiles()

Private slot to configure the various view profiles.

#### UserInterface.__connectToWebBrowser

__connectToWebBrowser(process)

Private method to connect to a started web browser.

process (QProcess)
  reference to the started web browser process

Return:
  error indication (1 = connection not possible, 0 = ok, -1 = server exited with an error code)

Return Type:
  int

#### UserInterface.__copyVersions

__copyVersions()

Private method to generated version information and copy that to the clipboard.

#### UserInterface.__crashSessionFilePath

__crashSessionFilePath(globPattern=False)

Private method to generate a path name for a unique crash session file.

globPattern (bool (optional))
  flag indicating to get the glob pattern for crash session files (defaults to False)

Return:
  crash session file path

Return Type:
  str

#### UserInterface.__createDockWindow

__createDockWindow(name)

Private method to create a dock window with common properties.

name (str)
  object name of the new dock window

Return:
  the generated dock window

Return Type:
  QDockWindow

#### UserInterface.__createLayout

__createLayout()

Private method to create the layout of the various windows.

Raises ValueError:
  raised to indicate an invalid layout type

#### UserInterface.__createObjects

__createObjects()

Private method to create the various application objects.

#### UserInterface.__createSidebarsLayout

__createSidebarsLayout()

Private method to create the Sidebars layout.

#### UserInterface.__createTestingDialog

__createTestingDialog()

Private slot to generate the testing dialog on demand.

#### UserInterface.__createToolboxesLayout

__createToolboxesLayout()

Private method to create the Toolboxes layout.

#### UserInterface.__customViewer

__customViewer(home=None)

Private slot to start a custom viewer.

home (str)
  full pathname of a file to display

#### UserInterface.__debuggingDone

__debuggingDone()

Private slot to handle the end of a debugging session.

#### UserInterface.__debuggingStarted

__debuggingStarted()

Private slot to handle the start of a debugging session.

#### UserInterface.__deinstallPlugin

__deinstallPlugin()

Private slot to show a dialog to uninstall a plugin.

#### UserInterface.__deleteCrashSession

__deleteCrashSession()

Private slot to delete the crash session file.

#### UserInterface.__designer

__designer(fn=None)

Private slot to start the Qt-Designer executable.

fn (str)
  filename of the form to be opened

#### UserInterface.__editPixmap

__editPixmap(fn="")

Private slot to show a pixmap in a dialog.

fn (str (optional))
  path of the file to show (defaults to "")

#### UserInterface.__editorOpened

__editorOpened(fn)

Private slot to handle the editorOpened signal.

fn (str)
  filename of the opened editor

#### UserInterface.__exportPreferences

__exportPreferences()

Private slot to export the current preferences.

#### UserInterface.__exportShortcuts

__exportShortcuts()

Private slot to export the keyboard shortcuts.

#### UserInterface.__exportTheme

__exportTheme()

Private slot to export the current theme to a file.

#### UserInterface.__getCrashedSessions

__getCrashedSessions()

Private method to get a list of crash session file paths of crashed sessions.

Note: Crashed sessions are those, whose PID does not exist anymore.

Return:
  list of crashed session file paths

Return Type:
  list of str

#### UserInterface.__getFloatingGeometry

__getFloatingGeometry(w)

Private method to get the geometry of a floating windows.

w (QWidget)
  reference to the widget to be saved

Return:
  list giving the widget's geometry and its visibility

Return Type:
  list of [int, int, int, int, bool]

#### UserInterface.__hToolboxCurrentChanged

__hToolboxCurrentChanged(index)

Private slot handling a change of the current index of the Horizontal Toolbox.

index (int)
  current index of the horizontal toolbox

#### UserInterface.__hasErrorLog

__hasErrorLog()

Private method to check, if an error log file exists.

Return:
  flag indicating the existence of an error log file

Return Type:
  bool

#### UserInterface.__helpViewer

__helpViewer()

Private slot to start an empty help viewer/web browser.

#### UserInterface.__importPreferences

__importPreferences()

Private slot to from eric7 import Preferences.

#### UserInterface.__importShortcuts

__importShortcuts()

Private slot to import the keyboard shortcuts.

#### UserInterface.__importTheme

__importTheme()

Private slot to import a previously exported theme.

#### UserInterface.__initActions

__initActions()

Private method to define the user interface actions.

#### UserInterface.__initDebugToolbarsLayout

__initDebugToolbarsLayout()

Private slot to initialize the toolbars layout for the debug profile.

#### UserInterface.__initEricDocAction

__initEricDocAction()

Private slot to initialize the action to show the eric documentation.

#### UserInterface.__initExternalToolsActions

__initExternalToolsActions()

Private slot to create actions for the configured external tools.

#### UserInterface.__initMenus

__initMenus()

Private slot to create the menus.

#### UserInterface.__initPySideDocActions

__initPySideDocActions()

Private slot to initialize the actions to show the PySide documentation.

#### UserInterface.__initPythonDocActions

__initPythonDocActions()

Private slot to initialize the actions to show the Python documentation.

#### UserInterface.__initQtDocActions

__initQtDocActions()

Private slot to initialize the action to show the Qt documentation.

#### UserInterface.__initStatusbar

__initStatusbar()

Private slot to set up the status bar.

#### UserInterface.__initToolbars

__initToolbars()

Private slot to create the toolbars.

#### UserInterface.__initToolsMenus

__initToolsMenus(menu)

Private slot to initialize the various tool menus.

menu (QMenu)
  reference to the parent menu

#### UserInterface.__installDownloadedPlugins

__installDownloadedPlugins()

Private slot to handle the installation of plugins downloaded via the plugin repository viewer.

#### UserInterface.__installPlugins

__installPlugins(pluginFileNames=None)

Private slot to show a dialog to install a new plugin.

pluginFileNames (list of str)
  list of plugin files suggested for installation

#### UserInterface.__ircAutoConnected

__ircAutoConnected()

Private slot handling the automatic connection of the IRC client.

#### UserInterface.__lastEditorClosed

__lastEditorClosed()

Private slot to handle the lastEditorClosed signal.

#### UserInterface.__launchExternalWebBrowser

__launchExternalWebBrowser(home, searchWord=None)

Private method to start an external web browser and communicate with it.

home (str)
  filename of file to be shown or URL to be opened
searchWord (str)
  word to search for

Return:
  flag indicating a successful launch

Return Type:
  bool

#### UserInterface.__linguist

__linguist(fn=None)

Private slot to start the Qt-Linguist executable.

fn (str)
  filename of the translation file to be opened

#### UserInterface.__loadCrashSession

__loadCrashSession()

Private slot to load a crash session.

#### UserInterface.__loadSessionFromFile

__loadSessionFromFile()

Private slot to load a session from disk.

#### UserInterface.__mainPasswordChanged

__mainPasswordChanged(oldPassword, newPassword)

Private slot to handle the change of the main password.

oldPassword (str)
  current main password
newPassword (str)
  new main password

#### UserInterface.__newProject

__newProject()

Private slot to handle the NewProject signal.

#### UserInterface.__newWindow

__newWindow()

Private slot to start a new instance of eric.

#### UserInterface.__onlineStateChanged

__onlineStateChanged(online)

Private slot handling changes in online state.

online (bool)
  flag indicating the online state

#### UserInterface.__openHexEditor

__openHexEditor(fn="")

Private slot to open the hex editor window.

fn (str (optional))
  path of the file to show (defaults to "")

#### UserInterface.__openMiniEditor

__openMiniEditor()

Private slot to show a mini editor window.

#### UserInterface.__openOnStartup

__openOnStartup(startupType=None)

Private method to open the last file, project or multiproject.

startupType (str)
  type of startup requested (one of "Nothing", "File", "Project", "MultiProject" or "Session")

#### UserInterface.__openPdfViewer

__openPdfViewer(fn="")

Private slot to open the PDF viewer window.

fn (str (optional))
  path of the file to show (defaults to "")

#### UserInterface.__performUpgrade

__performUpgrade(upgradeType)

Private method to perform the requested upgrade operation.

This action needs to shut down eric first, start a non-PyQt application performing the upgrade of the PyQt packages via pip and restart eric with the passed arguments. The upgrade process is not visible.

upgradeType (str)
  upgrade operation (one of 'eric', 'ericpyqt', 'pyqt')

#### UserInterface.__pluginInstallFinished

__pluginInstallFinished()

Private slot to handle the finishing of the plugin install dialog.

#### UserInterface.__pluginsConfigure

__pluginsConfigure()

Private slot to show the plugin manager configuration page.

#### UserInterface.__populateToolbarsMenu

__populateToolbarsMenu(menu)

Private method to populate a toolbars menu.

menu (QMenu)
  reference to the menu to be populated

#### UserInterface.__preferencesChanged

__preferencesChanged()

Private slot to handle a change of the preferences.

#### UserInterface.__processToolStderr

__processToolStderr()

Private slot to handle the readyReadStderr signal of a tool process.

#### UserInterface.__processToolStdout

__processToolStdout()

Private slot to handle the readyReadStdout signal of a tool process.

#### UserInterface.__programChange

__programChange(fn)

Private slot to handle the programChange signal.

This primarily is here to set the currentProg variable.

fn (str)
  filename to be set as current prog

#### UserInterface.__projectClosed

__projectClosed()

Private slot to handle the projectClosed signal.

#### UserInterface.__projectOpened

__projectOpened()

Private slot to handle the projectOpened signal.

#### UserInterface.__quit

__quit()

Private method to quit the application.

#### UserInterface.__readCrashSession

__readCrashSession()

Private method to check for and read a crash session.

Return:
  flag indicating a crash session file was found and read

Return Type:
  bool

#### UserInterface.__readSession

__readSession(filename="")

Private slot to read in the session file (.esj).

filename (str)
  name of a session file to read

Return:
  flag indicating success

Return Type:
  bool

#### UserInterface.__readTasks

__readTasks()

Private slot to read in the tasks file (.etj).

#### UserInterface.__reloadAPIs

__reloadAPIs()

Private slot to reload the api information.

#### UserInterface.__reportBug

__reportBug()

Private slot to handle the Report Bug dialog.

#### UserInterface.__requestFeature

__requestFeature()

Private slot to handle the Feature Request dialog.

#### UserInterface.__rerunFailedTests

__rerunFailedTests()

Private slot to display the testing dialog and rerun all failed tests of the last run.

#### UserInterface.__restart

__restart(ask=False)

Private method to restart the application.

ask (bool)
  flag indicating to ask the user for permission

#### UserInterface.__restartTest

__restartTest()

Private slot to display the testing dialog and rerun the last test run.

#### UserInterface.__saveCurrentViewProfile

__saveCurrentViewProfile(save)

Private slot to save the window geometries of the active profile.

save (bool)
  flag indicating that the current profile should be saved

#### UserInterface.__saveSessionToFile

__saveSessionToFile()

Private slot to save a session to disk.

#### UserInterface.__setEditProfile

__setEditProfile(save=True)

Private slot to activate the edit view profile.

save (bool)
  flag indicating that the current profile should be saved

#### UserInterface.__setWindowCaption

__setWindowCaption(editor=None, project=None)

Private method to set the caption of the Main Window.

editor (str)
  filename to be displayed
project (str)
  project name to be displayed

#### UserInterface.__setupDockWindow

__setupDockWindow(dock, where, widget, caption)

Private method to configure the dock window created with __createDockWindow().

dock (QDockWindow)
  the dock window
where (Qt.DockWidgetArea)
  dock area to be docked to
widget (QWidget)
  widget to be shown in the dock window
caption (str)
  caption of the dock window

#### UserInterface.__showCertificatesDialog

__showCertificatesDialog()

Private slot to show the certificates management dialog.

#### UserInterface.__showEricDoc

__showEricDoc()

Private slot to show the Eric documentation.

#### UserInterface.__showErrorLog

__showErrorLog()

Private slot to show the most recent error log message.

#### UserInterface.__showExternalTools

__showExternalTools()

Private slot to display a dialog show a list of external tools used by eric.

#### UserInterface.__showExtrasMenu

__showExtrasMenu()

Private slot to display the Extras menu.

#### UserInterface.__showFileMenu

__showFileMenu()

Private slot to display the File menu.

#### UserInterface.__showHelpMenu

__showHelpMenu()

Private slot to display the Help menu.

#### UserInterface.__showInstallInfo

__showInstallInfo()

Private slot to show a dialog containing information about the installation process.

#### UserInterface.__showNext

__showNext()

Private slot used to show the next tab or file.

#### UserInterface.__showPixmap

__showPixmap(fn)

Private slot to show a pixmap in a dialog.

fn (str (optional))
  path of the file to show (defaults to "")

#### UserInterface.__showPluginInfo

__showPluginInfo()

Private slot to show the plugin info dialog.

#### UserInterface.__showPluginToolsMenu

__showPluginToolsMenu()

Private slot to show the Plugin Tools menu.

#### UserInterface.__showPluginsAvailable

__showPluginsAvailable()

Private slot to show the plugins available for download.

#### UserInterface.__showPrevious

__showPrevious()

Private slot used to show the previous tab or file.

#### UserInterface.__showPyQtDoc

__showPyQtDoc(variant=5)

Private slot to show the PyQt5/6 documentation.

variant (int or str)
  PyQt variant to show documentation for (5 or 6)

#### UserInterface.__showPySideDoc

__showPySideDoc(variant=2)

Private slot to show the PySide2/PySide6 documentation.

variant (int or str)
  PySide variant (2 or 6)

#### UserInterface.__showPythonDoc

__showPythonDoc()

Private slot to show the Python 3 documentation.

#### UserInterface.__showQtDoc

__showQtDoc(version)

Private method to show the Qt documentation.

version (int)
  Qt version to show documentation for

#### UserInterface.__showSessionsMenu

__showSessionsMenu()

Private slot to mofify the state of some session actions.

#### UserInterface.__showSettingsMenu

__showSettingsMenu()

Private slot to show the Settings menu.

#### UserInterface.__showSubWindowMenu

__showSubWindowMenu()

Private slot to display the Window menu of the Window menu.

#### UserInterface.__showSvg

__showSvg(fn)

Private slot to show a SVG file in a dialog.

fn (str)
  filename of the file to show

#### UserInterface.__showSystemEmailClient

__showSystemEmailClient(mode, attachFile=None, deleteAttachFile=False)

Private slot to show the system email dialog.

mode (str)
  mode of the email dialog ("bug" or "feature")
attachFile (str)
  name of a file to put into the body of the email
deleteAttachFile (bool)
  flag indicating to delete the file after it has been read

#### UserInterface.__showToolGroupsMenu

__showToolGroupsMenu()

Private slot to display the Tool Groups menu.

#### UserInterface.__showToolbarsMenu

__showToolbarsMenu()

Private slot to display the Toolbars menu.

#### UserInterface.__showUml

__showUml(fn)

Private slot to show an eric graphics file in a dialog.

fn (str)
  name of the file to be shown

#### UserInterface.__showUserToolsMenu

__showUserToolsMenu()

Private slot to display the User Tools menu.

#### UserInterface.__showVersions

__showVersions()

Private slot to handle the Versions dialog.

#### UserInterface.__showWindowMenu

__showWindowMenu()

Private slot to display the Window menu.

#### UserInterface.__showWizardsMenu

__showWizardsMenu()

Private slot to display the Wizards menu.

#### UserInterface.__shutdown

__shutdown()

Private method to perform all necessary steps to close down the IDE.

Return:
  flag indicating success

Return Type:
  bool

#### UserInterface.__snapshot

__snapshot()

Private slot to start the snapshot tool.

#### UserInterface.__sqlBrowser

__sqlBrowser()

Private slot to start the SQL browser tool.

#### UserInterface.__sslErrors

__sslErrors(reply, errors)

Private slot to handle SSL errors.

reply (QNetworkReply)
  reference to the reply object
errors (list of QSslError)
  list of SSL errors

#### UserInterface.__startFido2SecurityKeyMgmt

__startFido2SecurityKeyMgmt()

Private slot to start the FIDO2 Security Key Management.

#### UserInterface.__startTestProject

__startTestProject()

Private slot for displaying the testing dialog and run the test for the current project.

#### UserInterface.__startTestScript

__startTestScript(testFile=None)

Private slot for displaying the testing dialog and run the current script.

testFile (str)
  file containing the tests to be run

#### UserInterface.__startTesting

__startTesting()

Private slot for displaying the testing dialog.

#### UserInterface.__startToolProcess

__startToolProcess(tool)

Private slot to start an external tool process.

tool (dict)
  dictionary of tool entries

#### UserInterface.__startWebBrowser

__startWebBrowser()

Private slot to start the eric web browser.

#### UserInterface.__switchTab

__switchTab()

Private slot used to switch between the current and the previous current tab.

#### UserInterface.__testingStopped

__testingStopped()

Private slot to handle the end of a test run.

#### UserInterface.__toggleBottomSidebar

__toggleBottomSidebar()

Private slot to handle the toggle of the bottom sidebar window.

#### UserInterface.__toggleHorizontalToolbox

__toggleHorizontalToolbox()

Private slot to handle the toggle of the Horizontal Toolbox window.

#### UserInterface.__toggleLeftSidebar

__toggleLeftSidebar()

Private slot to handle the toggle of the left sidebar window.

#### UserInterface.__toggleLeftToolbox

__toggleLeftToolbox()

Private slot to handle the toggle of the Left Toolbox window.

#### UserInterface.__toggleRightSidebar

__toggleRightSidebar()

Private slot to handle the toggle of the right sidebar window.

#### UserInterface.__toggleRightToolbox

__toggleRightToolbox()

Private slot to handle the toggle of the Right Toolbox window.

#### UserInterface.__toggleWindow

__toggleWindow(w)

Private method to toggle a workspace editor window.

w (Editor)
  reference to the workspace editor window

Return:
  flag indicating, if the window was shown

Return Type:
  bool

#### UserInterface.__toolActionTriggered

__toolActionTriggered(act)

Private slot called by external tools toolbar actions.

act (QAction)
  reference to the action that triggered the slot

#### UserInterface.__toolExecute

__toolExecute(act)

Private slot to execute a particular tool.

act (QAction)
  reference to the action that was triggered

#### UserInterface.__toolFinished

__toolFinished(exitCode, exitStatus)

Private slot to handle the finished signal of a tool process.

exitCode (int)
  exit code of the process
exitStatus (QProcess.ExitStatus)
  exit status of the process

#### UserInterface.__toolGroupSelected

__toolGroupSelected(act)

Private slot to set the current tool group.

act (QAction)
  reference to the action that was triggered

#### UserInterface.__toolGroupsConfiguration

__toolGroupsConfiguration()

Private slot to handle the tool groups configuration menu entry.

#### UserInterface.__toolsConfiguration

__toolsConfiguration()

Private slot to handle the tools configuration menu entry.

#### UserInterface.__updateExternalToolsActions

__updateExternalToolsActions()

Private method to update the external tools actions for the current tool group.

#### UserInterface.__webBrowser

__webBrowser(home="")

Private slot to start the eric web browser.

home (str)
  full pathname of a file to display

#### UserInterface.__webBrowserFinished

__webBrowserFinished()

Private slot handling the end of the external web browser process.

#### UserInterface.__webBrowserShutdown

__webBrowserShutdown()

Private method to shut down the web browser.

#### UserInterface.__whatsThis

__whatsThis()

Private slot called in to enter Whats This mode.

#### UserInterface.__writeCrashSession

__writeCrashSession()

Private slot to write a crash session file.

#### UserInterface.__writeSession

__writeSession(filename="")

Private slot to write the session data to a JSON file (.esj).

filename (str)
  name of a session file to write

Return:
  flag indicating success

Return Type:
  bool

#### UserInterface.__writeTasks

__writeTasks()

Private slot to write the tasks data to a JSON file (.etj).

#### UserInterface.activateCodeDocumentationViewer

activateCodeDocumentationViewer(switchFocus=True)

Public slot to handle the activation of the Code Documentation Viewer.

switchFocus (bool)
  flag indicating to transfer the input focus

#### UserInterface.activateCooperationViewer

activateCooperationViewer()

Public slot to handle the activation of the cooperation window.

#### UserInterface.activateDebugViewer

activateDebugViewer()

Public slot to handle the activation of the debug viewer.

#### UserInterface.activateLeftRightSidebarWidget

activateLeftRightSidebarWidget(widget)

Public method to activate the given widget in the left or right sidebar.

widget (QWidget)
  reference to the widget to be activated

#### UserInterface.activatePluginRepositoryViewer

activatePluginRepositoryViewer()

Public slot to activate the plugin repository viewer.

#### UserInterface.activateVirtualenvManager

activateVirtualenvManager()

Public slot to activate the virtual environments manager widget.

#### UserInterface.addEricActions

addEricActions(actions, actionType)

Public method to add actions to the list of actions.

actions (list of EricAction)
  list of actions to be added
actionType (str)
  string denoting the action set to add to. It must be one of "ui" or "wizards".

#### UserInterface.addSideWidget

addSideWidget(side, widget, icon, label)

Public method to add a widget to the sides.

side (UserInterfaceSide)
  side to add the widget to
widget (QWidget)
  reference to the widget to add
icon (QIcon)
  icon to be used
label (str)
  label text to be shown

#### UserInterface.appendToStderr

appendToStderr(s)

Public slot to append text to the stderr log viewer tab.

s (str)
  output to be appended

#### UserInterface.appendToStdout

appendToStdout(s)

Public slot to append text to the stdout log viewer tab.

s (str)
  output to be appended

#### UserInterface.autoConnectIrc

autoConnectIrc()

Public method to initiate the IRC auto connection.

#### UserInterface.checkConfigurationStatus

checkConfigurationStatus()

Public method to check, if eric has been configured. If it is not, the configuration dialog is shown.

#### UserInterface.checkForErrorLog

checkForErrorLog()

Public method to check for the presence of an error log and ask the user, what to do with it.

#### UserInterface.checkPluginUpdatesAvailable

checkPluginUpdatesAvailable()

Public method to check the availability of updates of plug-ins.

#### UserInterface.checkProjectsWorkspace

checkProjectsWorkspace()

Public method to check, if a projects workspace has been configured. If it has not, a dialog is shown.

#### UserInterface.closeEvent

closeEvent(event)

Protected event handler for the close event.

This event handler saves the preferences.

event (QCloseEvent)
  close event

#### UserInterface.createPopupMenu

createPopupMenu()

Public method to create the toolbars menu for Qt.

Return:
  toolbars menu

Return Type:
  QMenu

#### UserInterface.documentationViewer

documentationViewer()

Public method to provide a reference to the code documentation viewer.

Return:
  reference to the code documentation viewer

Return Type:
  CodeDocumentationViewer

#### UserInterface.dragEnterEvent

dragEnterEvent(event)

Protected method to handle the drag enter event.

event (QDragEnterEvent)
  the drag enter event

#### UserInterface.dragLeaveEvent

dragLeaveEvent(event)

Protected method to handle the drag leave event.

event (QDragLeaveEvent)
  the drag leave event

#### UserInterface.dragMoveEvent

dragMoveEvent(event)

Protected method to handle the drag move event.

event (QDragMoveEvent)
  the drag move event

#### UserInterface.dropEvent

dropEvent(event)

Protected method to handle the drop event.

event (QDropEvent)
  the drop event

#### UserInterface.getActions

getActions(actionType)

Public method to get a list of all actions.

actionType (str)
  string denoting the action set to get. It must be one of "ui" or "wizards".

Return:
  list of all actions

Return Type:
  list of EricAction

#### UserInterface.getLayoutType

getLayoutType()

Public method to get the current layout type.

Return:
  current layout type

Return Type:
  str

#### UserInterface.getLocale

getLocale()

Public method to get the locale of the IDE.

Return:
  locale of the IDE

Return Type:
  str

#### UserInterface.getMenu

getMenu(name)

Public method to get a reference to a specific menu.

name (str)
  name of the menu

Return:
  reference to the menu

Return Type:
  QMenu

#### UserInterface.getMenuAction

getMenuAction(menuName, actionName)

Public method to get a reference to an action of a menu.

menuName (str)
  name of the menu to search in
actionName (str)
  object name of the action to search for

Return:
  reference to the menu action

Return Type:
  QAction

#### UserInterface.getMenuBarAction

getMenuBarAction(menuName)

Public method to get a reference to an action of the main menu.

menuName (str)
  name of the menu to search in

Return:
  reference to the menu bar action

Return Type:
  QAction

#### UserInterface.getOriginalPathString

getOriginalPathString()

Public method to get the original PATH environment variable (i.e. before modifications by eric and PyQt5).

Return:
  original PATH environment variable

Return Type:
  str

#### UserInterface.getToolbar

getToolbar(name)

Public method to get a reference to a specific toolbar.

name (str)
  name of the toolbar

Return:
  reference to the toolbar entry

Return Type:
  tuple of (str, QToolBar)

#### UserInterface.getToolbarsByCategory

getToolbarsByCategory(category)

Public method to get a list of toolbars belonging to a given toolbar category.

category (str)
  toolbar category

Return:
  list of toolbars

Return Type:
  list of QToolBar

#### UserInterface.getViewProfile

getViewProfile()

Public method to get the current view profile.

Return:
  the name of the current view profile

Return Type:
  str

#### UserInterface.handleUrl

handleUrl(url)

Public slot to handle opening a URL.

url (QUrl)
  URL to be shown

#### UserInterface.isEricServerConnected

isEricServerConnected()

Public method to check, if a connection to an eric-ide server has been established.

Return:
  flag indicating the interface connection state

Return Type:
  bool

#### UserInterface.isOnline

isOnline()

Public method to get the online state.

Return:
  online state

Return Type:
  bool

#### UserInterface.launchHelpViewer

launchHelpViewer(home, searchWord=None)

Public slot to start the help viewer/web browser.

home (str or QUrl)
  filename of file to be shown or URL to be opened
searchWord (str)
  word to search for

#### UserInterface.networkAccessManager

networkAccessManager()

Public method to get a reference to the network access manager object.

Return:
  reference to the network access manager object

Return Type:
  QNetworkAccessManager

#### UserInterface.performVersionCheck

performVersionCheck()

Public method to check for an update even if not installed via PyPI.

#### UserInterface.processArgs

processArgs(args)

Public method to process the command line args passed to the UI.

args (argparse.Namespace)
  namespace object containing the parsed command line parameters

#### UserInterface.processInstallInfoFile

processInstallInfoFile()

Public method to process the file containing installation information.

#### UserInterface.registerToolbar

registerToolbar(name, text, toolbar, category="")

Public method to register a toolbar.

This method must be called in order to make a toolbar manageable by the UserInterface object.

name (str)
  name of the toolbar. This is used as the key into the dictionary of toolbar references.
text (str)
  user visible text for the toolbar entry
toolbar (QToolBar)
  reference to the toolbar to be registered
category (str)
  toolbar category

Raises KeyError:
  raised, if a toolbar with the given name was already registered

#### UserInterface.removeEricActions

removeEricActions(actions, actionType="ui")

Public method to remove actions from the list of actions.

actions (list of EricActio)
  list of actions
actionType (str)
  string denoting the action set to remove from. It must be one of "ui" or "wizards".

#### UserInterface.removeSideWidget

removeSideWidget(widget)

Public method to remove a widget added using addSideWidget().

widget (QWidget)
  reference to the widget to remove

#### UserInterface.reregisterToolbar

reregisterToolbar(name, text, category="")

Public method to change the visible text for the named toolbar.

name (str)
  name of the toolbar to be changed
text (str)
  new user visible text for the toolbar entry
category (str)
  new toolbar category for the toolbar entry

#### UserInterface.setDebugProfile

setDebugProfile(save=True)

Public slot to activate the debug view profile.

save (bool)
  flag indicating that the current profile should be saved

#### UserInterface.setLeftRightSidebarWidgetIcon

setLeftRightSidebarWidgetIcon(widget, icon)

Public method to set the icon of the given widget in the left or right sidebar.

widget (QWidget)
  reference to the widget to set the icon for
icon (QIcon)
  icon to be set

#### UserInterface.showEmailDialog

showEmailDialog(mode, attachFile=None, deleteAttachFile=False)

Public slot to show the email dialog in a given mode.

mode (str)
  mode of the email dialog ("bug" or "feature")
attachFile (str)
  name of a file to attach to the email
deleteAttachFile (bool)
  flag indicating to delete the attached file after it has been sent

#### UserInterface.showEvent

showEvent(_evt)

Protected method to handle the show event.

_evt (QShowEvent)
  reference to the show event (unused)

#### UserInterface.showFindFileByNameDialog

showFindFileByNameDialog()

Public slot to show the Find File by Name dialog.

#### UserInterface.showFindFilesWidget

showFindFilesWidget(txt="", searchDir="", openFiles=False)

Public slot to show the Find In Files widget.

txt (str (optional))
  text to search for (defaults to "")
searchDir (str (optional))
  directory to search in (defaults to "")
openFiles (bool (optional))
  flag indicating to operate on open files only (defaults to False)

#### UserInterface.showFindLocationWidget

showFindLocationWidget()

Public method to show the Find File widget.

#### UserInterface.showLogViewer

showLogViewer()

Public method to show the Log-Viewer.

#### UserInterface.showNotification

showNotification(icon, heading, text, kind=NotificationTypes.INFORMATION, timeout=None)

Public method to show a desktop notification.

icon (QPixmap)
  icon to be shown in the notification
heading (str)
  heading of the notification
text (str)
  text of the notification
kind (NotificationTypes)
  kind of notification to be shown
timeout (int)
  time in seconds the notification should be shown (None = use configured timeout, 0 = indefinitely)

#### UserInterface.showPreferences

showPreferences(pageName=None)

Public slot to set the preferences.

pageName (str)
  name of the configuration page to show

#### UserInterface.showReplaceFilesWidget

showReplaceFilesWidget(txt="", searchDir="", openFiles=False)

Public slot to show the Find In Files widget in replace mode.

txt (str (optional))
  text to search for (defaults to "")
searchDir (str (optional))
  directory to search in (defaults to "")
openFiles (bool (optional))
  flag indicating to operate on open files only (defaults to False)

#### UserInterface.showSideWidget

showSideWidget(widget)

Public method to show a specific widget placed in the side widgets.

widget (QWidget)
  reference to the widget to be shown

#### UserInterface.unregisterToolbar

unregisterToolbar(name)

Public method to unregister a toolbar.

name (str)
  name of the toolbar

#### UserInterface.upgradeEric

upgradeEric()

Public slot to upgrade the eric-ide package of the eric7 environment.

Return:
  flag indicating a successful upgrade

Return Type:
  bool

#### UserInterface.upgradeEricPyQt

upgradeEricPyQt()

Public slot to upgrade the eric-ide and PyQt packages of the eric7 environment.

Return:
  flag indicating a successful upgrade

Return Type:
  bool

#### UserInterface.upgradePyQt

upgradePyQt()

Public slot to upgrade the PyQt packages of the eric7 environment.

Return:
  flag indicating a successful upgrade

Return Type:
  bool

#### UserInterface.versionIsNewer

versionIsNewer(required, snapshot=None)

Public method to check, if the eric version is good compared to the required version.

required (str)
  required version
snapshot (str)
  required snapshot version

Return:
  flag indicating, that the version is newer than the required one

Return Type:
  bool

Up

## UserInterfaceSide

Class defining the supported sides of the user interface.

### Derived from

enum.Enum

### Class Attributes

Bottom
Left
Right

### Class Methods

None

### Methods

None

### Static Methods

None

Up